API Reference
=============

`neurodiffeq.neurodiffeq`
------------------------------------------------------
.. automodule:: neurodiffeq.neurodiffeq
    :show-inheritance:
    :inherited-members:
    :members:

`neurodiffeq.networks`
------------------------------------------------------
.. automodule:: neurodiffeq.networks
    :show-inheritance:
    :inherited-members:
    :members:

`neurodiffeq.conditions`
------------------------------------------------------
.. automodule:: neurodiffeq.conditions
    :show-inheritance:
    :inherited-members:
    :members:

`neurodiffeq.solvers`
------------------------------------------------------
.. automodule:: neurodiffeq.solvers
    :show-inheritance:
    :inherited-members:
    :members:

`neurodiffeq.monitors`
------------------------------------------------------
.. automodule:: neurodiffeq.monitors
    :show-inheritance:
    :inherited-members:
    :members:

`neurodiffeq.ode`
------------------------------------------------------
.. automodule:: neurodiffeq.ode
    :show-inheritance:
    :inherited-members:
    :members:

`neurodiffeq.pde`
------------------------------------------------------
.. automodule:: neurodiffeq.pde
    :show-inheritance:
    :inherited-members:
    :members:

`neurodiffeq.pde_spherical`
------------------------------------------------------
.. automodule:: neurodiffeq.pde_spherical
    :show-inheritance:
    :inherited-members:
    :members:

`neurodiffeq.temporal`
------------------------------------------------------
.. automodule:: neurodiffeq.temporal
    :show-inheritance:
    :inherited-members:
    :members:

`neurodiffeq.function_basis`
------------------------------------------------------
.. automodule:: neurodiffeq.function_basis
    :show-inheritance:
    :inherited-members:
    :members:

`neurodiffeq.generators`
------------------------------------------------------
.. automodule:: neurodiffeq.generators
    :show-inheritance:
    :inherited-members:
    :members:

`neurodiffeq.operators`
------------------------------------------------------
.. automodule:: neurodiffeq.operators
    :show-inheritance:
    :inherited-members:
    :members:

`neurodiffeq.callbacks`
------------------------------------------------------
.. automodule:: neurodiffeq.callbacks
    :show-inheritance:
    :inherited-members:
    :members:

`neurodiffeq.utils`
------------------------------------------------------
.. automodule:: neurodiffeq.utils
    :show-inheritance:
    :inherited-members:
    :members:

